@@ -1,3 +1,3 @@
 from ._query_manager import QueryManager
 
-__all__ = ['QueryManager']
\ No newline at end of file
+__all__ = ["QueryManager"]
